[Telepathy-commits] [telepathy-gabble/master] add reference to fixed fd.o#19327 to NEWS and test source

Senko Rasic senko.rasic at collabora.co.uk
Tue Jan 20 03:13:17 PST 2009


---
 NEWS                                               |    2 ++
 .../twisted/jingle/test-content-adding-removal.py  |    7 ++++++-
 2 files changed, 8 insertions(+), 1 deletions(-)

diff --git a/NEWS b/NEWS
index c93e488..0614cc0 100644
--- a/NEWS
+++ b/NEWS
@@ -4,6 +4,8 @@ telepathy-gabble 0.7.19 (UNRELEASED)
 Fixes:
 
 * Don't crash when closing a muc channel containing an closed D-Bus tube.
+* Don't resurrect removed streams if the call responder includes them in
+  session-initiate (fd.o #19327).
 
 telepathy-gabble 0.7.18 (2009-01-06)
 ====================================
diff --git a/tests/twisted/jingle/test-content-adding-removal.py b/tests/twisted/jingle/test-content-adding-removal.py
index 28ca897..fdac485 100644
--- a/tests/twisted/jingle/test-content-adding-removal.py
+++ b/tests/twisted/jingle/test-content-adding-removal.py
@@ -3,6 +3,9 @@ Test content adding and removal during the session. We start
 session with only one stream, then add one more, then remove
 the first one and lastly remove the second stream, which
 closes the session.
+
+Also does regression test for http://bugs.freedesktop.org/show_bug.cgi?id=19327
+
 """
 
 from gabbletest import exec_test, make_result_iq, sync_stream, \
@@ -103,7 +106,9 @@ def test(q, bus, conn, stream):
 
     # Only now the remote end removes the video stream; if gabble mistakenly
     # marked it as accepted on session acceptance, it'll crash right about
-    # now. If it's good, stream will be really removed, and we can proceed.
+    # now (fd.o #19327). If it's good, stream will be really removed, and
+    # we can proceed.
+
     stream.send(gabbletest.make_result_iq(stream, e2.stanza))
 
     q.expect('dbus-signal', signal='StreamRemoved')
-- 
1.5.6.5




More information about the Telepathy-commits mailing list